@@ -167,6 +167,81 @@ sub _split_top_level_semicolons {
     return @parts;
 }
 
+sub _split_top_level_pipes {
+    my ($text) = @_;
+
+    return unless defined $text;
+
+    my %pairs = (
+        '(' => ')',
+        '[' => ']',
+        '{' => '}',
+    );
+    my %closing = reverse %pairs;
+
+    my @stack;
+    my $string;
+    my $escape = 0;
+    my @parts;
+    my $start = 0;
+
+    my $length = length $text;
+    for (my $i = 0; $i < $length; $i++) {
+        my $char = substr($text, $i, 1);
+
+        if (defined $string) {
+            if ($escape) {
+                $escape = 0;
+                next;
+            }
+
+            if ($char eq '\\') {
+                $escape = 1;
+                next;
+            }
+
+            if ($char eq $string) {
+                undef $string;
+            }
+
+            next;
+        }
+
+        if ($char eq "'" || $char eq '"') {
+            $string = $char;
+            next;
+        }
+
+        if (exists $pairs{$char}) {
+            push @stack, $char;
+            next;
+        }
+
+        if (exists $closing{$char}) {
+            return unless @stack;
+            my $open = pop @stack;
+            return unless $pairs{$open} eq $char;
+            next;
+        }
+
+        next unless $char eq '|';
+        if (substr($text, $i, 2) eq '||') {
+            $i++;
+            next;
+        }
+
+        if (!@stack) {
+            my $chunk = substr($text, $start, $i - $start);
+            push @parts, $chunk;
+            $start = $i + 1;
+        }
+    }
+
+    push @parts, substr($text, $start) if $start <= $length;
+
+    return @parts;
+}
+
 sub _split_top_level_commas {
     my ($text) = @_;
 
